==> sparnatural-8.0.0.tgz: package/docs/index.md <==

# Sparnatural documentation

[![French](https://github.com/madebybowtie/FlagKit/raw/master/Assets/PNG/FR.png) Documentation en français](/fr)

_For examples of how Sparnatural works and can be configured, have a look at the [**demos folder**](https://github.com/sparna-git/sparnatural.eu/tree/main/demos) of [sparnatural.eu](http://sparnatural.eu) website._

### Configuration

  - [OWL-based configuration](OWL-based-configuration) - Reference page and how-to for the OWL-based configuration
  - [OWL-based configuration : datasources](OWL-based-configuration-datasources)  - Reference page and how-to to configure the datasources on properties or classes
  - [JSON-based configuration](JSON-based-configuration) - Reference page for the JSON-based configuration
  - [Integration with GraphDB Lucene Connector](Integration-with-GraphDB-Lucene-Connector) - Special configuration to interact with a GraphDB Lucene index 
  - [Querying date ranges](Querying-date-ranges) - How to generate SPARQL queries that can match on resources with a begin date and a end date 
  - [FAQ](FAQ) - Frequently Asked Questions, mostly about configuration 

### Integration in webpages

  - [Javascript integration](Javascript-integration) - Reference page for Javascript integration and parameters for version 8
  - [Javascript integration v7](Javascript-integration-v7) - Reference page for Javascript integration and parameters for version 7
  - [Query JSON format](Query-JSON-format) - Documentation on the JSON structure used by Sparnatural to output and reload queries
  - [Querying a password protected SPARQL endpoint](Querying-a-password-protected-SPARQL-endpoint)
  - [SPARQL service integration](SPARQL-service-integration) - **/!\ deprecated** How to fetch autocomplete results and list contents from a SPARQL endpoint

  
### For developers

  - [Developing and Compiling](Developing-and-Compiling) - How to make modifications to the source code in a development environment and recompile Sparnatural
  - [Internal](Internal) - **/!\ deprecated** Internal code structure documentation

==> sparnatural-8.1.0.tgz: package/docs/index.md <==

# Sparnatural documentation

[![French](https://github.com/madebybowtie/FlagKit/raw/master/Assets/PNG/FR.png) Documentation en français](/fr)

_For examples of how Sparnatural works and can be configured, have a look at the [**demos folder**](https://github.com/sparna-git/sparnatural.eu/tree/main/demos) of [sparnatural.eu](http://sparnatural.eu) website._

### Configuration
Currently there are two ways to configure Sparnatural:

1. Configure via OWL-Protege
  - [OWL-based configuration](OWL-based-configuration) - Reference page and how-to for the OWL-based configuration
  - [OWL-based configuration : datasources](OWL-based-configuration-datasources)  - Reference page and how-to to configure the datasources on properties or classes

2. Configure via JSON
  - [JSON-based configuration](JSON-based-configuration) - Reference page for the JSON-based configuration

Other configuration related topics:
  - [Integration with GraphDB Lucene Connector](Integration-with-GraphDB-Lucene-Connector) - Special configuration to interact with a GraphDB Lucene index 
  - [Querying date ranges](Querying-date-ranges) - How to generate SPARQL queries that can match on resources with a begin date and a end date 
  - [FAQ](FAQ) - Frequently Asked Questions, mostly about configuration 

### Integration in webpages

  - [Javascript integration v8](Javascript-integration) - Reference page for Javascript integration and parameters for version 8
  - [React integration v8](react-integration) - Initialization of Sparnatural as a custom component within react
  - [Javascript integration v7](Javascript-integration-v7) - Reference page for Javascript integration and parameters for version 7
  - [Customize colors](Customize-colors) - How to customize colors of Sparnatural
  - [Query JSON format](Query-JSON-format) - Documentation on the JSON structure used by Sparnatural to output and reload queries
  - [Querying a password protected SPARQL endpoint](Querying-a-password-protected-SPARQL-endpoint)

  
### For developers

  - [Developing and Compiling](Developing-and-Compiling) - How to make modifications to the source code in a development environment and recompile Sparnatural
